"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AWSSecretsManager = void 0;
const tslib_1 = require("tslib");
require("dotenv/config");
const client_secrets_manager_1 = require("@aws-sdk/client-secrets-manager");
class AWSSecretsManager {
    constructor(config) {
        this.client = new client_secrets_manager_1.SecretsManagerClient({ region: config.region || "sa-east-1" });
        this.secretsMap = config.secretsMap;
    }
    static create(config) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const secretsManager = new AWSSecretsManager(config);
            yield secretsManager.loadSecrets();
            return secretsManager;
        });
    }
    loadSecrets() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (process.env.NODE_ENV === "prod") {
                console.log("Production environment detected. Loading AWS SDK...");
                for (const [envKey, secretId] of Object.entries(this.secretsMap)) {
                    yield this.fetchAndSetSecret(envKey, secretId);
                }
            }
            else {
                console.log("Development environment detected. Using local process.env.");
            }
        });
    }
    fetchAndSetSecret(envKey, secretId) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this.client.send(new client_secrets_manager_1.GetSecretValueCommand({
                    SecretId: secretId,
                    VersionStage: "AWSCURRENT",
                }));
                console.log(`Secret ${envKey} loaded successfully.`);
                const secretValue = response.SecretString ? JSON.parse(response.SecretString) : null;
                if (secretValue && typeof secretValue === "object") {
                    process.env[envKey] = secretValue[envKey] || secretValue;
                }
            }
            catch (error) {
                console.error(`Failed to fetch secret for ${envKey}:`, error);
            }
        });
    }
}
exports.AWSSecretsManager = AWSSecretsManager;
//# sourceMappingURL=aws-secrets-manager.js.map